Context

Struct Context 

pub struct Context {
    pub params: Vec<Captures<'static, 'static>>,
    /* private fields */
}
The context of a request.

This is a wrapper around a crate::http::Request and a crate::http::Response that provides access to the request and response as well as some additional information such as the state and parameters.

Fields

params: Vec<Captures<'static, 'static>>

Any error captured during the request. The parsed request parameters

Implementations

Source

impl Context

pub fn try_borrow<T: 'static>(&self) -> Option<&T>

Try borrow a context value

pub fn borrow<T: 'static>(&self) -> &T

Borrow a context value Panics if the value does not exist

pub fn try_borrow_mut<T: 'static>(&mut self) -> Option<&mut T>

Try borrow a mutable context value

pub fn borrow_mut<T: 'static>(&mut self) -> &mut T

Borrow a mutable context value Panics if the value does not exist

pub fn try_take<T: 'static>(&mut self) -> Option<T>

Try take a context value

pub fn take<T: 'static>(&mut self) -> T

Take a context value Panics if the value does not exist

pub fn insert<T: Send + Sync + 'static>(&mut self, value: T) -> Option<T>

Insert a context value

pub fn param(&self, key: &str) -> Result<&str>

Extract and parse a route parameter by name.

Returns the parameter as a &str, borrowed from this Request.

The name should not include the leading :.

Errors

An error is returned if key is not a valid parameter for the route.

pub fn wildcard(&self) -> Option<&str>

Fetch the wildcard from the route, if it exists

Returns the parameter as a &str, borrowed from this Request.